@@ -1,10 +1,10 @@
 import os
 import sys
 from pathlib import Path
-import shutil
 from typing import Optional
 import datetime
 import hashlib
+from .logger import Logger
 
 SESSION_DIR_KEY = 'LAUNCHABLE_SESSION_DIR'
 DEFAULT_SESSION_DIR = '~/.config/launchable/sessions/'
@@ -19,21 +19,33 @@ def _session_file_path(build_name: str) -> Path:
 
 
 def _get_session_id() -> str:
+    # CircleCI changes unix session id each steps, so set non change variable
+    # https://circleci.com/docs/2.0/env-vars/#built-in-environment-variables
+    if os.environ.get("CIRCLECI") is not None:
+        id = os.environ.get("CIRCLE_WORKFLOW_ID")
+        if id is not None:
+             return id
+        Logger().warning("CIRCLECI environment variable is set but not CIRCLE_WORKFLOW_ID")
+
+    # Jenkins pipeline also launches every process as a new session, so better to scope this to a particular build.
+    # For freestyle job types that do not do this, session IDs do not distinguish different builds, so that is a problem, too.
+    #
+    # See: https://github.com/jenkinsci/lib-durable-task/blob/6e020747205cb5aca5af757bc0d2a302c42bdb79/src/cmd/bash/durable_task_monitor.go#L41
+    # See: https://www.jenkins.io/doc/book/pipeline/jenkinsfile/#using-environment-variables
+    if os.environ.get("JENKINS_URL") is not None:
+        id = os.environ.get("BUILD_URL")
+        if id is not None:
+            return id
+        Logger().warning("JENKINS_URL environment variable is set but not BUILD_URL")
+
     if sys.platform == "win32":
         import wmi # type: ignore
         c = wmi.WMI()
         wql = "Associators of {{Win32_Process='{}'}} Where Resultclass = Win32_LogonSession Assocclass = Win32_SessionProcess".format(os.getpid())
         res = c.query(wql)
-        id = res[0].LogonId
+        return str(res[0].LogonId)
     else:
-        id = str(os.getsid(os.getpid()))
-
-    # CircleCI changes unix session id each steps, so set non change variable
-    # https://circleci.com/docs/2.0/env-vars/#built-in-environment-variables
-    if os.environ.get("CIRCLECI") is not None:
-        id = os.environ.get("CIRCLE_WORKFLOW_ID") or ""
-
-    return id
+        return str(os.getsid(os.getpid()))
 
 
 def read_session(build_name: str) -> Optional[str]:
@@ -88,10 +100,9 @@ def clean_session_files(days_ago: int = 0) -> None:
 def parse_session(session: str):
     try:
         # session format:
-        # /intake/organizations/<org name>/workspaces/<workspace name>/builds/<build name>/test_sessions/<test session id>
-        _, _, _, org, _, workspace, _, build_name, _, session_id = session.split(
-            "/")
+        # builds/<build name>/test_sessions/<test session id>
+        _, build_name, _, session_id = session.split("/")
     except Exception as e:
         raise Exception("Can't parse session: {}".format(session)) from e
 
-    return org, workspace, build_name, session_id
+    return build_name, session_id
